@@ -1,5 +1,6 @@
 import sure
-from .fake_module import fake_datetime_function, fake_date_function
+import time
+from .fake_module import fake_datetime_function, fake_date_function, fake_time_function
 from freezegun import freeze_time
 from freezegun.api import FakeDatetime
 import datetime
@@ -16,6 +17,14 @@ def test_import_date_works():
     fake_date_function().day.should.equal(14)
 
 
+@freeze_time("2012-01-14")
+def test_import_time():
+    local_time = datetime.datetime(2012, 1, 14)
+    utc_time = local_time - datetime.timedelta(seconds=time.timezone)
+    expected_timestamp = time.mktime(utc_time.timetuple())
+    fake_time_function().should.equal(expected_timestamp)
+
+
 def test_start_and_stop_works():
     freezer = freeze_time("2012-01-14")
 
